from pseudopeople.__about__ import (
    __author__,
    __copyright__,
    __email__,
    __license__,
    __summary__,
    __title__,
    __uri__,
    __version__,
)
from pseudopeople.interface import generate_decennial_census, generate_w2
